Project

Struct Project 

pub struct Project {
    pub file_contents: Querry<FileContents>,
    pub syntax: Querry<Syntax>,
    pub exports: Querry<Exports>,
    pub bindings: Querry<Bindings>,
    /* private fields */
}
Global project data

Fields

file_contents: Querry<FileContents>syntax: Querry<Syntax>exports: Querry<Exports>bindings: Querry<Bindings>

Implementations

Source

impl Project

pub fn new(root: Option<PathBuf>) -> Self

pub fn initialize(&mut self)

pub fn load_config(&mut self)

(Re)load project config files

pub fn lookup_file(&self, path: &Path) -> FileHandle

pub fn make_dummy_file(&mut self) -> FileHandle

pub fn get_file(&self, file: FileHandle) -> Arc<File>

pub fn get_pkg(&self, pkg: PkgHandle) -> &Package

pub fn try_pkg_for_file(&self, file: FileHandle) -> Option<PkgHandle>

Lookup a PkgHandle for a given source path.

pub fn pkg_for_file(&mut self, file: FileHandle) -> PkgHandle

Get a PkgHandle for a given source path, if one does not already exist, a dummy package will be created.

pub fn add_ovelay(&mut self, file: FileHandle, text: String)

Used to manually control contents of file at given path. Aka.: this is where textDocument/did{Open,Change} notifications go

pub fn remove_overlay(&mut self, file: FileHandle)

Remove overlay status for a file. Aka.: textDocument/didClose

pub fn file_contents( &self, file: FileHandle, as_pkg: PkgHandle, ) -> Arc<FileContents>

pub fn iter_packages(&self) -> impl Iterator<Item = PkgHandle>